Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(262)

Unified Diff: runtime/vm/intrinsifier.cc

Issue 10877030: Fix inlining and intrinsification for moved Math methods. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/intrinsifier.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/intrinsifier.cc
===================================================================
--- runtime/vm/intrinsifier.cc (revision 11200)
+++ runtime/vm/intrinsifier.cc (working copy)
@@ -55,11 +55,13 @@
const char* function_name = String::Handle(function.name()).ToCString();
const Class& function_class = Class::Handle(function.Owner());
const char* class_name = String::Handle(function_class.Name()).ToCString();
// Only core library methods can be intrinsified.
const Library& core_lib = Library::Handle(Library::CoreLibrary());
const Library& core_impl_lib = Library::Handle(Library::CoreImplLibrary());
+ const Library& math_lib = Library::Handle(Library::MathLibrary());
if ((function_class.library() != core_lib.raw()) &&
- (function_class.library() != core_impl_lib.raw())) {
+ (function_class.library() != core_impl_lib.raw()) &&
+ (function_class.library() != math_lib.raw())) {
return false;
}
#define FIND_INTRINSICS(test_class_name, test_function_name, destination) \
@@ -55,11 +55,13 @@
const Class& function_class = Class::Handle(function.Owner());
const char* class_name = String::Handle(function_class.Name()).ToCString();
- // Only core library methods can be intrinsified.
+ // Only core and math library methods can be intrinsified.
const Library& core_lib = Library::Handle(Library::CoreLibrary());
const Library& core_impl_lib = Library::Handle(Library::CoreImplLibrary());
« no previous file with comments | « runtime/vm/intrinsifier.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698